@@ -66,12 +66,12 @@ function set_tag_data(&$tag) {
     /* ɥᥤ̾ */
     $domain = "";
     if (isset($mod_data["domain"]) === TRUE) {
-        $domain = htmlspecialchars($mod_data["domain"]);
+        $domain = escape_html($mod_data["domain"]);
     }
 
     $disp_dom = "";
     if (isset($mod_data["disp_dom"]) === TRUE) {
-        $disp_dom = htmlspecialchars($mod_data["disp_dom"]);
+        $disp_dom = escape_html($mod_data["disp_dom"]);
     }
 
     /* ѥ */
@@ -88,7 +88,7 @@ function set_tag_data(&$tag) {
     /* ̥ѥ */
     $indivipass = "";
     if (isset($mod_data["indivipass"]) === TRUE) {
-        $indivipass = htmlspecialchars($mod_data["indivipass"]);
+        $indivipass = escape_html($mod_data["indivipass"]);
     }
 
     /* Ź沽롼 */
@@ -388,7 +388,7 @@ if (isset($_POST["mod"]) === TRUE) {
 /* 󥻥 */
 } elseif (isset($_POST["cancel"]) === TRUE) {
     /* ̤ */
-    dgp_location("index.php", $del_list);
+    dgp_location("index.php");
     exit (0);
 
 }
