@@ -76,7 +76,7 @@ function set_tag_data(&$tag) {
     }
 
     /*  */
-    $domain = htmlspecialchars($domain);
+    $domain = escape_html($domain);
 
     $tag["<<DOMAIN>>"] = $domain;
     $tag["<<SENDER_NAME>>"] = $sender_name;
@@ -279,7 +279,7 @@ if (isset($_POST["mod"]) === TRUE) {
 } elseif (isset($_POST["cancel"]) === TRUE) {
 
     /* ɥᥤ̤ */
-    dgp_location("index.php", $del_list);
+    dgp_location("index.php");
     exit (0);
 }
 
