@@ -63,7 +63,7 @@ function set_tag_data(&$tag) {
     global $templ_data;
 
     /* html */
-    $cnv_templ_data = htmlspecialchars($templ_data);
+    $cnv_templ_data = escape_html($templ_data);
     $tag["<<CNV_TMPL_DATA>>"] = $cnv_templ_data;
 
     return TRUE;
