@@ -95,7 +95,7 @@ function print_result(&$looptag)
         }
 
         /*  */
-        $domain = htmlspecialchars($domain);
+        $domain = escape_html($domain);
         $cnv_key = str_replace("'", "\'", $key);
 
         $looptag[$domain_count]["<<KEY>>"] = $key;
@@ -132,7 +132,7 @@ if ($ret === FALSE) {
 
 /* å */
 if (isset($_POST["msg"]) === TRUE) {
-    $err_msg = htmlspecialchars($_POST["msg"]);
+    $err_msg = escape_html($_POST["msg"]);
 }
 
 /***********************************************************
@@ -152,7 +152,7 @@ if ($ret === FALSE) {
 }
 
 $dispusr = $web_conf[$url_data['script']]['displayuser'];
-$dispusr = htmlspecialchars($ldapdata[0][$dispusr][0]);
+$dispusr = escape_html($ldapdata[0][$dispusr][0]);
 
 /* ݻͼ */
 $del_list = "";
@@ -164,7 +164,7 @@ if (isset($_POST["delete"]) === TRUE) {
 /* ɲ */
 if (isset($_POST["new_add"]) === TRUE) {
     /* ɲò̤ */
-    dgp_location("samma_add.php", $del_list);
+    dgp_location("samma_add.php");
     exit (0);
 
 /* åΤ */
